@@ -172,9 +172,8 @@ def start():
 
     with open("{}/source/auth_key.tl".format(HOME), encoding="utf-8") as auth, \
             open("{}/source/sys_msgs.tl".format(HOME), encoding="utf-8") as system, \
-            open("{}/source/main_api.tl".format(HOME), encoding="utf-8") as api, \
-            open("{}/source/pyrogram.tl".format(HOME), encoding="utf-8") as pyrogram:
-        schema = (auth.read() + system.read() + api.read() + pyrogram.read()).splitlines()
+            open("{}/source/main_api.tl".format(HOME), encoding="utf-8") as api:
+        schema = (auth.read() + system.read() + api.read()).splitlines()
 
     with open("{}/template/mtproto.txt".format(HOME), encoding="utf-8") as f:
         mtproto_template = f.read()
@@ -494,17 +493,19 @@ def start():
         f.write("\n    0xb0700015: \"pyrogram.client.types.ChatPhoto\",")
         f.write("\n    0xb0700016: \"pyrogram.client.types.ChatMember\",")
         f.write("\n    0xb0700017: \"pyrogram.client.types.Sticker\",")
-        f.write("\n    0xb0700025: \"pyrogram.client.types.GIF\",")
+        f.write("\n    0xb0700018: \"pyrogram.client.types.bots.ForceReply\",")
+        f.write("\n    0xb0700019: \"pyrogram.client.types.bots.InlineKeyboardButton\",")
+        f.write("\n    0xb0700020: \"pyrogram.client.types.bots.InlineKeyboardMarkup\",")
+        f.write("\n    0xb0700021: \"pyrogram.client.types.bots.KeyboardButton\",")
+        f.write("\n    0xb0700022: \"pyrogram.client.types.bots.ReplyKeyboardMarkup\",")
+        f.write("\n    0xb0700023: \"pyrogram.client.types.bots.ReplyKeyboardRemove\",")
+        f.write("\n    0xb0700024: \"pyrogram.client.types.CallbackQuery\",")
+        f.write("\n    0xb0700025: \"pyrogram.client.types.Animation\",")
         f.write("\n    0xb0700026: \"pyrogram.client.types.Messages\",")
-
-        f.write("\n    0xb0700018: \"pyrogram.client.types.reply_markup.ForceReply\",")
-        f.write("\n    0xb0700019: \"pyrogram.client.types.reply_markup.InlineKeyboardButton\",")
-        f.write("\n    0xb0700020: \"pyrogram.client.types.reply_markup.InlineKeyboardMarkup\",")
-        f.write("\n    0xb0700021: \"pyrogram.client.types.reply_markup.KeyboardButton\",")
-        f.write("\n    0xb0700022: \"pyrogram.client.types.reply_markup.ReplyKeyboardMarkup\",")
-        f.write("\n    0xb0700023: \"pyrogram.client.types.reply_markup.ReplyKeyboardRemove\",")
-
-        f.write("\n    0xb0700024: \"pyrogram.client.types.CallbackQuery\"")
+        f.write("\n    0xb0700027: \"pyrogram.client.types.Photo\",")
+        f.write("\n    0xb0700028: \"pyrogram.client.types.Dialog\",")
+        f.write("\n    0xb0700029: \"pyrogram.client.types.Dialogs\",")
+        f.write("\n    0xb0700030: \"pyrogram.client.types.ChatMembers\",")
 
         f.write("\n}\n")
 
