@@ -16,6 +16,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
+import logging
 from collections import OrderedDict
 from datetime import datetime
 from io import BytesIO
@@ -23,13 +24,23 @@ from json import JSONEncoder, dumps
 
 from ..all import objects
 
+log = logging.getLogger(__name__)
+
 
 class Object:
     all = {}
 
     @staticmethod
     def read(b: BytesIO, *args):
-        return Object.all[int.from_bytes(b.read(4), "little")].read(b, *args)
+        constructor_id = int.from_bytes(b.read(4), "little")
+
+        try:
+            return Object.all[constructor_id].read(b, *args)
+        except KeyError:
+            log.error("Unknown constructor found: {}. Full data: {}".format(
+                hex(constructor_id),
+                b.getvalue().hex())
+            )
 
     def write(self, *args) -> bytes:
         pass
@@ -37,6 +48,9 @@ class Object:
     def __str__(self) -> str:
         return dumps(self, cls=Encoder, indent=4)
 
+    def __bool__(self) -> bool:
+        return True
+
     def __eq__(self, other) -> bool:
         return self.__dict__ == other.__dict__
 
@@ -46,6 +60,18 @@ class Object:
     def __call__(self):
         pass
 
+    def __getitem__(self, item):
+        return getattr(self, item)
+
+
+def remove_none(obj):
+    if isinstance(obj, (list, tuple, set)):
+        return type(obj)(remove_none(x) for x in obj if x is not None)
+    elif isinstance(obj, dict):
+        return type(obj)((remove_none(k), remove_none(v)) for k, v in obj.items() if k is not None and v is not None)
+    else:
+        return obj
+
 
 class Encoder(JSONEncoder):
     def default(self, o: Object):
@@ -57,7 +83,19 @@ class Encoder(JSONEncoder):
             else:
                 return repr(o)
 
-        return OrderedDict(
-            [("_", objects.get(getattr(o, "ID", None), None))]
-            + [i for i in content.items()]
-        )
+        name = o.__class__.__name__
+        o = objects.get(getattr(o, "ID", None), None)
+
+        if o is not None:
+            if o.startswith("pyrogram.client"):
+                r = remove_none(OrderedDict([("_", "pyrogram:" + name)] + [i for i in content.items()]))
+                r.pop("_client", None)
+
+                return r
+            else:
+                return OrderedDict(
+                    [("_", o.replace("pyrogram.api.types.", "telegram:"))]
+                    + [i for i in content.items()]
+                )
+        else:
+            return None
