@@ -16,4 +16,8 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
-from .handlers import MessageHandler, CallbackQueryHandler, RawUpdateHandler
+from .callback_query_handler import CallbackQueryHandler
+from .disconnect_handler import DisconnectHandler
+from .message_handler import MessageHandler
+from .deleted_messages_handler import DeletedMessagesHandler
+from .raw_update_handler import RawUpdateHandler
